==> huaweicloudsdkgaussdbfornosql-3.1.137-py2.py3-none-any.whl: huaweicloudsdkgaussdbfornosql/v3/model/list_instance_maintenance_window_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListInstanceMaintenanceWindowResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'maintenance_window': 'str'
    }

    attribute_map = {
        'maintenance_window': 'maintenance_window'
    }

    def __init__(self, maintenance_window=None):
        """ListInstanceMaintenanceWindowResponse

        The model defined in huaweicloud sdk

        :param maintenance_window: 参数解释： 实例的可维护时间窗。
        :type maintenance_window: str
        """
        
        super(ListInstanceMaintenanceWindowResponse, self).__init__()

        self._maintenance_window = None
        self.discriminator = None

        if maintenance_window is not None:
            self.maintenance_window = maintenance_window

    @property
    def maintenance_window(self):
        """Gets the maintenance_window of this ListInstanceMaintenanceWindowResponse.

        参数解释： 实例的可维护时间窗。

        :return: The maintenance_window of this ListInstanceMaintenanceWindowResponse.
        :rtype: str
        """
        return self._maintenance_window

    @maintenance_window.setter
    def maintenance_window(self, maintenance_window):
        """Sets the maintenance_window of this ListInstanceMaintenanceWindowResponse.

        参数解释： 实例的可维护时间窗。

        :param maintenance_window: The maintenance_window of this ListInstanceMaintenanceWindowResponse.
        :type maintenance_window: str
        """
        self._maintenance_window = maintenance_window

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListInstanceMaintenanceWindowResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkgaussdbfornosql-3.1.149-py2.py3-none-any.whl: huaweicloudsdkgaussdbfornosql/v3/model/list_instance_maintenance_window_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListInstanceMaintenanceWindowResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'maintenance_window': 'str'
    }

    attribute_map = {
        'maintenance_window': 'maintenance_window'
    }

    def __init__(self, maintenance_window=None):
        r"""ListInstanceMaintenanceWindowResponse

        The model defined in huaweicloud sdk

        :param maintenance_window: 参数解释： 实例的可维护时间窗。
        :type maintenance_window: str
        """
        
        super(ListInstanceMaintenanceWindowResponse, self).__init__()

        self._maintenance_window = None
        self.discriminator = None

        if maintenance_window is not None:
            self.maintenance_window = maintenance_window

    @property
    def maintenance_window(self):
        r"""Gets the maintenance_window of this ListInstanceMaintenanceWindowResponse.

        参数解释： 实例的可维护时间窗。

        :return: The maintenance_window of this ListInstanceMaintenanceWindowResponse.
        :rtype: str
        """
        return self._maintenance_window

    @maintenance_window.setter
    def maintenance_window(self, maintenance_window):
        r"""Sets the maintenance_window of this ListInstanceMaintenanceWindowResponse.

        参数解释： 实例的可维护时间窗。

        :param maintenance_window: The maintenance_window of this ListInstanceMaintenanceWindowResponse.
        :type maintenance_window: str
        """
        self._maintenance_window = maintenance_window

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListInstanceMaintenanceWindowResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
